summaryrefslogtreecommitdiffstats
path: root/src/H5Omessage.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2007-02-06 12:18:05 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2007-02-06 12:18:05 (GMT)
commit571523db1ffab60b505a0f66d3f7c25f4d1752d7 (patch)
treec3da7f1799eb8048885c4ce2b5372ba5fd3c183a /src/H5Omessage.c
parent4e57d80f2e085a80dfe5f55a39c15e1edc4366f9 (diff)
downloadhdf5-571523db1ffab60b505a0f66d3f7c25f4d1752d7.zip
hdf5-571523db1ffab60b505a0f66d3f7c25f4d1752d7.tar.gz
hdf5-571523db1ffab60b505a0f66d3f7c25f4d1752d7.tar.bz2
[svn-r13243] Description:
Add API routines for tracking & indexing the creation order on attributes. Tested on: Mac OS X/32 10.4.8 (amazon) FreeBSD/32 6.2 (duty)
Diffstat (limited to 'src/H5Omessage.c')
-rw-r--r--src/H5Omessage.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/H5Omessage.c b/src/H5Omessage.c
index d598819..2831d6b 100644
--- a/src/H5Omessage.c
+++ b/src/H5Omessage.c
@@ -1681,7 +1681,7 @@ done:
*/
unsigned
H5O_msg_alloc(H5F_t *f, hid_t dxpl_id, H5O_t *oh, const H5O_msg_class_t *type,
- unsigned *mesg_flags, void *mesg, unsigned *oh_flags_ptr)
+ unsigned *mesg_flags, void *native, unsigned *oh_flags_ptr)
{
htri_t shared_mesg; /* Should this message be stored in the Shared Message table? */
unsigned ret_value = UFAIL; /* Return value */
@@ -1694,15 +1694,15 @@ H5O_msg_alloc(H5F_t *f, hid_t dxpl_id, H5O_t *oh, const H5O_msg_class_t *type,
HDassert(mesg_flags);
HDassert(!(*mesg_flags & H5O_MSG_FLAG_SHARED));
HDassert(type);
- HDassert(mesg);
+ HDassert(native);
HDassert(oh_flags_ptr);
/* Check if message is already shared */
- if((shared_mesg = H5O_msg_is_shared(type->id, mesg)) < 0)
+ if((shared_mesg = H5O_msg_is_shared(type->id, native)) < 0)
HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, UFAIL, "error determining if message is shared")
else if(shared_mesg > 0) {
/* Increment message's reference count */
- if(type->link && (type->link)(f, dxpl_id, mesg) < 0)
+ if(type->link && (type->link)(f, dxpl_id, native) < 0)
HGOTO_ERROR(H5E_OHDR, H5E_LINKCOUNT, UFAIL, "unable to adjust shared message ref count")
*mesg_flags |= H5O_MSG_FLAG_SHARED;
} /* end if */
@@ -1710,7 +1710,7 @@ H5O_msg_alloc(H5F_t *f, hid_t dxpl_id, H5O_t *oh, const H5O_msg_class_t *type,
/* Avoid unsharable messages */
if(!(*mesg_flags & H5O_MSG_FLAG_DONTSHARE)) {
/* Attempt to share message */
- if((shared_mesg = H5SM_try_share(f, dxpl_id, type->id, mesg)) > 0)
+ if((shared_mesg = H5SM_try_share(f, dxpl_id, type->id, native)) > 0)
/* Mark the message as shared */
*mesg_flags |= H5O_MSG_FLAG_SHARED;
else if(shared_mesg < 0)
@@ -1719,13 +1719,13 @@ H5O_msg_alloc(H5F_t *f, hid_t dxpl_id, H5O_t *oh, const H5O_msg_class_t *type,
} /* end else */
/* Allocate space in the object header for the message */
- if((ret_value = H5O_alloc(f, dxpl_id, oh, type, mesg, oh_flags_ptr)) == UFAIL)
+ if((ret_value = H5O_alloc(f, dxpl_id, oh, type, native, oh_flags_ptr)) == UFAIL)
HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, UFAIL, "unable to allocate space for message")
/* Get the message's "creation index", if it has one */
if(type->get_crt_index) {
- /* Retrieve the creation index for the message */
- if((type->get_crt_index)(mesg, &oh->mesg[ret_value].crt_idx) < 0)
+ /* Retrieve the creation index from the native message */
+ if((type->get_crt_index)(native, &oh->mesg[ret_value].crt_idx) < 0)
HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, UFAIL, "unable to retrieve creation index")
} /* end if */